timeseries.jagged — GDA Toolbox v1.0 Manual

# timeseries.jagged

`timeseries.` `jagged`(persdiag, index)

  Produce a piecewise-linear function that matches the given persistence diagram. This assumes that the index for the vertices is sequential and linear, so that the mergetree can be ignored.

  Parameters: | persdiag : `homology.PersDiag` A 0-dimensional persistence diagram index : list-like The domain index for the function
  Returns: | function : `pandas.Series`

  See also

  `timeseries.Signal.jagged()`
    func:timeseries.Signal.makepers

#### Previous topic

multidim.models.GaussianMixtureClassifier.set_params

#### Next topic

timeseries.test_mollifier